@@ -21,17 +21,21 @@ final class InvalidArgumentException extends Exception
 {
     public static function create(int $argument, string $type): self
     {
-        $stack = debug_backtrace();
+        $stack    = debug_backtrace();
+        $function = $stack[1]['function'];
+
+        if (isset($stack[1]['class'])) {
+            $function = sprintf('%s::%s', $stack[1]['class'], $stack[1]['function']);
+        }
 
         return new self(
             sprintf(
-                'Argument #%d of %s::%s() must be %s %s',
+                'Argument #%d of %s() must be %s %s',
                 $argument,
-                $stack[1]['class'],
-                $stack[1]['function'],
+                $function,
                 in_array(lcfirst($type)[0], ['a', 'e', 'i', 'o', 'u'], true) ? 'an' : 'a',
-                $type
-            )
+                $type,
+            ),
         );
     }
 
