@@ -20,10 +20,10 @@ final class CannotUseOnlyMethodsException extends \PHPUnit\Framework\Exception i
     {
         parent::__construct(
             sprintf(
-                'Trying to set mock method "%s" with onlyMethods, but it does not exist in class "%s". Use addMethods() for methods that do not exist in the class',
+                'Trying to configure method "%s" with onlyMethods(), but it does not exist in class "%s". Use addMethods() for methods that do not exist in the class',
                 $methodName,
-                $type
-            )
+                $type,
+            ),
         );
     }
 }
