@@ -91,8 +91,8 @@ final class PhptTestCase implements Reorderable, SelfDescribing, Test
             throw new Exception(
                 sprintf(
                     'File "%s" does not exist.',
-                    $filename
-                )
+                    $filename,
+                ),
             );
         }
 
@@ -223,7 +223,7 @@ final class PhptTestCase implements Reorderable, SelfDescribing, Test
                     $trace[0]['file'],
                     $trace[0]['line'],
                     $trace,
-                    $comparisonFailure ? $diff : ''
+                    $comparisonFailure ? $diff : '',
                 );
             }
 
@@ -408,7 +408,7 @@ final class PhptTestCase implements Reorderable, SelfDescribing, Test
             $result->addFailure(
                 $this,
                 new SyntheticSkippedError($message, 0, $trace[0]['file'], $trace[0]['line'], $trace),
-                0
+                0,
             );
             $result->endTest($this, 0);
 
@@ -489,7 +489,7 @@ final class PhptTestCase implements Reorderable, SelfDescribing, Test
         foreach ($unsupportedSections as $section) {
             if (isset($sections[$section])) {
                 throw new Exception(
-                    "PHPUnit does not support PHPT {$section} sections"
+                    "PHPUnit does not support PHPT {$section} sections",
                 );
             }
         }
@@ -520,8 +520,8 @@ final class PhptTestCase implements Reorderable, SelfDescribing, Test
                         sprintf(
                             'Could not load --%s-- %s for PHPT file',
                             $section . '_EXTERNAL',
-                            $testDirectory . $externalFilename
-                        )
+                            $testDirectory . $externalFilename,
+                        ),
                     );
                 }
 
@@ -579,7 +579,7 @@ final class PhptTestCase implements Reorderable, SelfDescribing, Test
                 "'" . dirname($this->filename) . "'",
                 "'" . $this->filename . "'",
             ],
-            $code
+            $code,
         );
     }
 
@@ -599,12 +599,12 @@ final class PhptTestCase implements Reorderable, SelfDescribing, Test
         $files = $this->getCoverageFiles();
 
         $template = new Template(
-            __DIR__ . '/../Util/PHP/Template/PhptTestCase.tpl'
+            __DIR__ . '/../Util/PHP/Template/PhptTestCase.tpl',
         );
 
         $composerAutoload = '\'\'';
 
-        if (defined('PHPUNIT_COMPOSER_INSTALL') && !defined('PHPUNIT_TESTSUITE')) {
+        if (defined('PHPUNIT_COMPOSER_INSTALL')) {
             $composerAutoload = var_export(PHPUNIT_COMPOSER_INSTALL, true);
         }
 
@@ -619,7 +619,7 @@ final class PhptTestCase implements Reorderable, SelfDescribing, Test
         if (!empty($GLOBALS['__PHPUNIT_BOOTSTRAP'])) {
             $globals = '$GLOBALS[\'__PHPUNIT_BOOTSTRAP\'] = ' . var_export(
                 $GLOBALS['__PHPUNIT_BOOTSTRAP'],
-                true
+                true,
             ) . ";\n";
         }
 
@@ -638,7 +638,7 @@ final class PhptTestCase implements Reorderable, SelfDescribing, Test
                 'coverageFile'               => $files['coverage'],
                 'driverMethod'               => $pathCoverage ? 'forLineAndPathCoverage' : 'forLineCoverage',
                 'codeCoverageCacheDirectory' => $codeCoverageCacheDirectory,
-            ]
+            ],
         );
 
         file_put_contents($files['job'], $job);
