@@ -16,13 +16,16 @@ use function array_keys;
 use function assert;
 use function class_exists;
 use function copy;
+use function explode;
 use function extension_loaded;
 use function fgets;
 use function file_get_contents;
 use function file_put_contents;
+use function get_class;
 use function getcwd;
 use function ini_get;
 use function ini_set;
+use function is_array;
 use function is_callable;
 use function is_dir;
 use function is_file;
@@ -97,7 +100,7 @@ class Command
             throw new RuntimeException(
                 $t->getMessage(),
                 (int) $t->getCode(),
-                $t
+                $t,
             );
         }
     }
@@ -116,7 +119,7 @@ class Command
         } else {
             $suite = $runner->getTest(
                 $this->arguments['test'],
-                $this->arguments['testSuffixes']
+                $this->arguments['testSuffixes'],
             );
         }
 
@@ -254,8 +257,8 @@ class Command
             $this->exitWithErrorMessage(
                 sprintf(
                     'unrecognized --order-by option: %s',
-                    $arguments->unrecognizedOrderBy()
-                )
+                    $arguments->unrecognizedOrderBy(),
+                ),
             );
         }
 
@@ -268,7 +271,7 @@ class Command
         if ($arguments->hasIncludePath()) {
             ini_set(
                 'include_path',
-                $arguments->includePath() . PATH_SEPARATOR . ini_get('include_path')
+                $arguments->includePath() . PATH_SEPARATOR . ini_get('include_path'),
             );
         }
 
@@ -288,8 +291,8 @@ class Command
                 $this->exitWithErrorMessage(
                     sprintf(
                         'Cannot open file "%s".',
-                        $arguments->argument()
-                    )
+                        $arguments->argument(),
+                    ),
                 );
             }
         }
@@ -365,7 +368,7 @@ class Command
 
                 $this->arguments['printer'] = $this->handlePrinter(
                     $phpunitConfiguration->printerClass(),
-                    $file
+                    $file,
                 );
             }
 
@@ -374,7 +377,7 @@ class Command
 
                 $this->arguments['loader'] = $this->handleLoader(
                     $phpunitConfiguration->testSuiteLoaderClass(),
-                    $file
+                    $file,
                 );
             }
 
@@ -386,7 +389,7 @@ class Command
                 try {
                     $this->arguments['test'] = (new TestSuiteMapper)->map(
                         $this->arguments['configurationObject']->testSuite(),
-                        $this->arguments['testsuite'] ?? ''
+                        $this->arguments['testsuite'] ?? '',
                     );
                 } catch (Exception $e) {
                     $this->printVersionString();
@@ -427,7 +430,7 @@ class Command
         if (!class_exists($loaderClass, false)) {
             if ($loaderFile == '') {
                 $loaderFile = Filesystem::classNameToFilename(
-                    $loaderClass
+                    $loaderClass,
                 );
             }
 
@@ -436,6 +439,7 @@ class Command
             if ($loaderFile) {
                 /**
                  * @noinspection PhpIncludeInspection
+                 *
                  * @psalm-suppress UnresolvableInclude
                  */
                 require $loaderFile;
@@ -449,8 +453,8 @@ class Command
             } catch (\ReflectionException $e) {
                 throw new ReflectionException(
                     $e->getMessage(),
-                    (int) $e->getCode(),
-                    $e
+                    $e->getCode(),
+                    $e,
                 );
             }
             // @codeCoverageIgnoreEnd
@@ -471,8 +475,8 @@ class Command
         $this->exitWithErrorMessage(
             sprintf(
                 'Could not use "%s" as loader.',
-                $loaderClass
-            )
+                $loaderClass,
+            ),
         );
 
         return null;
@@ -488,7 +492,7 @@ class Command
         if (!class_exists($printerClass, false)) {
             if ($printerFile === '') {
                 $printerFile = Filesystem::classNameToFilename(
-                    $printerClass
+                    $printerClass,
                 );
             }
 
@@ -497,6 +501,7 @@ class Command
             if ($printerFile) {
                 /**
                  * @noinspection PhpIncludeInspection
+                 *
                  * @psalm-suppress UnresolvableInclude
                  */
                 require $printerFile;
@@ -507,8 +512,8 @@ class Command
             $this->exitWithErrorMessage(
                 sprintf(
                     'Could not use "%s" as printer: class does not exist',
-                    $printerClass
-                )
+                    $printerClass,
+                ),
             );
         }
 
@@ -518,8 +523,8 @@ class Command
         } catch (\ReflectionException $e) {
             throw new ReflectionException(
                 $e->getMessage(),
-                (int) $e->getCode(),
-                $e
+                $e->getCode(),
+                $e,
             );
             // @codeCoverageIgnoreEnd
         }
@@ -529,8 +534,8 @@ class Command
                 sprintf(
                     'Could not use "%s" as printer: class does not implement %s',
                     $printerClass,
-                    ResultPrinter::class
-                )
+                    ResultPrinter::class,
+                ),
             );
         }
 
@@ -538,8 +543,8 @@ class Command
             $this->exitWithErrorMessage(
                 sprintf(
                     'Could not use "%s" as printer: class cannot be instantiated',
-                    $printerClass
-                )
+                    $printerClass,
+                ),
             );
         }
 
@@ -560,7 +565,33 @@ class Command
         try {
             FileLoader::checkAndLoad($filename);
         } catch (Throwable $t) {
-            $this->exitWithErrorMessage($t->getMessage());
+            if ($t instanceof \PHPUnit\Exception) {
+                $this->exitWithErrorMessage($t->getMessage());
+            }
+
+            $message = sprintf(
+                'Error in bootstrap script: %s:%s%s%s%s',
+                get_class($t),
+                PHP_EOL,
+                $t->getMessage(),
+                PHP_EOL,
+                $t->getTraceAsString(),
+            );
+
+            while ($t = $t->getPrevious()) {
+                $message .= sprintf(
+                    '%s%sPrevious error: %s:%s%s%s%s',
+                    PHP_EOL,
+                    PHP_EOL,
+                    get_class($t),
+                    PHP_EOL,
+                    $t->getMessage(),
+                    PHP_EOL,
+                    $t->getTraceAsString(),
+                );
+            }
+
+            $this->exitWithErrorMessage($message);
         }
     }
 
@@ -568,19 +599,33 @@ class Command
     {
         $this->printVersionString();
 
-        $latestVersion = file_get_contents('https://phar.phpunit.de/latest-version-of/phpunit');
-        $isOutdated    = version_compare($latestVersion, Version::id(), '>');
+        $latestVersion           = file_get_contents('https://phar.phpunit.de/latest-version-of/phpunit');
+        $latestCompatibleVersion = file_get_contents('https://phar.phpunit.de/latest-version-of/phpunit-' . explode('.', Version::series())[0]);
 
-        if ($isOutdated) {
-            printf(
-                'You are not using the latest version of PHPUnit.' . PHP_EOL .
-                'The latest version is PHPUnit %s.' . PHP_EOL,
-                $latestVersion
-            );
+        $notLatest           = version_compare($latestVersion, Version::id(), '>');
+        $notLatestCompatible = version_compare($latestCompatibleVersion, Version::id(), '>');
+
+        if ($notLatest || $notLatestCompatible) {
+            print 'You are not using the latest version of PHPUnit.' . PHP_EOL;
         } else {
             print 'You are using the latest version of PHPUnit.' . PHP_EOL;
         }
 
+        if ($notLatestCompatible) {
+            printf(
+                'The latest version compatible with PHPUnit %s is PHPUnit %s.' . PHP_EOL,
+                Version::id(),
+                $latestCompatibleVersion,
+            );
+        }
+
+        if ($notLatest) {
+            printf(
+                'The latest version is PHPUnit %s.' . PHP_EOL,
+                $latestVersion,
+            );
+        }
+
         exit(TestRunner::SUCCESS_EXIT);
     }
 
@@ -624,6 +669,16 @@ class Command
     {
         $this->printVersionString();
 
+        $this->warnAboutConflictingOptions(
+            'listGroups',
+            [
+                'filter',
+                'groups',
+                'excludeGroups',
+                'testsuite',
+            ],
+        );
+
         print 'Available test group(s):' . PHP_EOL;
 
         $groups = $suite->getGroups();
@@ -636,7 +691,7 @@ class Command
 
             printf(
                 ' - %s' . PHP_EOL,
-                $group
+                $group,
             );
         }
 
@@ -649,18 +704,28 @@ class Command
 
     /**
      * @throws \PHPUnit\Framework\Exception
-     * @throws \PHPUnit\TextUI\XmlConfiguration\Exception
+     * @throws XmlConfiguration\Exception
      */
     private function handleListSuites(bool $exit): int
     {
         $this->printVersionString();
 
+        $this->warnAboutConflictingOptions(
+            'listSuites',
+            [
+                'filter',
+                'groups',
+                'excludeGroups',
+                'testsuite',
+            ],
+        );
+
         print 'Available test suite(s):' . PHP_EOL;
 
         foreach ($this->arguments['configurationObject']->testSuite() as $testSuite) {
             printf(
                 ' - %s' . PHP_EOL,
-                $testSuite->name()
+                $testSuite->name(),
             );
         }
 
@@ -678,6 +743,15 @@ class Command
     {
         $this->printVersionString();
 
+        $this->warnAboutConflictingOptions(
+            'listTests',
+            [
+                'filter',
+                'groups',
+                'excludeGroups',
+            ],
+        );
+
         $renderer = new TextTestListRenderer;
 
         print $renderer->render($suite);
@@ -696,13 +770,22 @@ class Command
     {
         $this->printVersionString();
 
+        $this->warnAboutConflictingOptions(
+            'listTestsXml',
+            [
+                'filter',
+                'groups',
+                'excludeGroups',
+            ],
+        );
+
         $renderer = new XmlTestListRenderer;
 
         file_put_contents($target, $renderer->render($suite));
 
         printf(
             'Wrote list of tests that would have been run to %s' . PHP_EOL,
-            $target
+            $target,
         );
 
         if ($exit) {
@@ -758,8 +841,8 @@ class Command
                 $bootstrapScript,
                 $testsDirectory,
                 $src,
-                $cacheDirectory
-            )
+                $cacheDirectory,
+            ),
         );
 
         print PHP_EOL . 'Generated phpunit.xml in ' . getcwd() . '.' . PHP_EOL;
@@ -772,7 +855,16 @@ class Command
     {
         $this->printVersionString();
 
-        if (!(new SchemaDetector)->detect($filename)->detected()) {
+        $result = (new SchemaDetector)->detect($filename);
+
+        if (!$result->detected()) {
+            print $filename . ' does not validate against any known schema.' . PHP_EOL;
+
+            exit(TestRunner::EXCEPTION_EXIT);
+        }
+
+        /** @psalm-suppress MissingThrowsDocblock */
+        if ($result->version() === Version::series()) {
             print $filename . ' does not need to be migrated.' . PHP_EOL;
 
             exit(TestRunner::EXCEPTION_EXIT);
@@ -785,7 +877,7 @@ class Command
         try {
             file_put_contents(
                 $filename,
-                (new Migrator)->migrate($filename)
+                (new Migrator)->migrate($filename),
             );
 
             print 'Migrated configuration: ' . $filename . PHP_EOL;
@@ -838,7 +930,7 @@ class Command
         if ($configuration->codeCoverage()->hasNonEmptyListOfFilesToBeIncludedInCodeCoverageReport()) {
             (new FilterMapper)->map(
                 $filter,
-                $configuration->codeCoverage()
+                $configuration->codeCoverage(),
             );
         } elseif (isset($this->arguments['coverageFilter'])) {
             if (!is_array($this->arguments['coverageFilter'])) {
@@ -865,7 +957,7 @@ class Command
             $cacheDirectory,
             !$configuration->codeCoverage()->disableCodeCoverageIgnore(),
             $configuration->codeCoverage()->ignoreDeprecatedCodeUnits(),
-            $filter
+            $filter,
         );
 
         print 'done [' . $timer->stop()->asString() . ']' . PHP_EOL;
@@ -888,4 +980,62 @@ class Command
 
         return null;
     }
+
+    /**
+     * @psalm-param "listGroups"|"listSuites"|"listTests"|"listTestsXml"|"filter"|"groups"|"excludeGroups"|"testsuite" $key
+     * @psalm-param list<"listGroups"|"listSuites"|"listTests"|"listTestsXml"|"filter"|"groups"|"excludeGroups"|"testsuite"> $keys
+     */
+    private function warnAboutConflictingOptions(string $key, array $keys): void
+    {
+        $warningPrinted = false;
+
+        foreach ($keys as $_key) {
+            if (!empty($this->arguments[$_key])) {
+                printf(
+                    'The %s and %s options cannot be combined, %s is ignored' . PHP_EOL,
+                    $this->mapKeyToOptionForWarning($_key),
+                    $this->mapKeyToOptionForWarning($key),
+                    $this->mapKeyToOptionForWarning($_key),
+                );
+
+                $warningPrinted = true;
+            }
+        }
+
+        if ($warningPrinted) {
+            print PHP_EOL;
+        }
+    }
+
+    /**
+     * @psalm-param "listGroups"|"listSuites"|"listTests"|"listTestsXml"|"filter"|"groups"|"excludeGroups"|"testsuite" $key
+     */
+    private function mapKeyToOptionForWarning(string $key): string
+    {
+        switch ($key) {
+            case 'listGroups':
+                return '--list-groups';
+
+            case 'listSuites':
+                return '--list-suites';
+
+            case 'listTests':
+                return '--list-tests';
+
+            case 'listTestsXml':
+                return '--list-tests-xml';
+
+            case 'filter':
+                return '--filter';
+
+            case 'groups':
+                return '--group';
+
+            case 'excludeGroups':
+                return '--exclude-group';
+
+            case 'testsuite':
+                return '--testsuite';
+        }
+    }
 }
