@@ -135,8 +135,8 @@ final class TestRunner extends BaseTestRunner
 
     /**
      * @throws \PHPUnit\Runner\Exception
-     * @throws \PHPUnit\TextUI\XmlConfiguration\Exception
      * @throws Exception
+     * @throws XmlConfiguration\Exception
      */
     public function run(TestSuite $suite, array $arguments = [], array $warnings = [], bool $exit = true): TestResult
     {
@@ -307,7 +307,7 @@ final class TestRunner extends BaseTestRunner
                         throw new Exception(
                             $e->getMessage(),
                             $e->getCode(),
-                            $e
+                            $e,
                         );
                     }
                     // @codeCoverageIgnoreEnd
@@ -341,8 +341,8 @@ final class TestRunner extends BaseTestRunner
                 new HtmlResultPrinter(
                     $arguments['testdoxHTMLFile'],
                     $arguments['testdoxGroups'],
-                    $arguments['testdoxExcludeGroups']
-                )
+                    $arguments['testdoxExcludeGroups'],
+                ),
             );
         }
 
@@ -351,22 +351,22 @@ final class TestRunner extends BaseTestRunner
                 new TextResultPrinter(
                     $arguments['testdoxTextFile'],
                     $arguments['testdoxGroups'],
-                    $arguments['testdoxExcludeGroups']
-                )
+                    $arguments['testdoxExcludeGroups'],
+                ),
             );
         }
 
         if (isset($arguments['testdoxXMLFile'])) {
             $result->addListener(
                 new XmlResultPrinter(
-                    $arguments['testdoxXMLFile']
-                )
+                    $arguments['testdoxXMLFile'],
+                ),
             );
         }
 
         if (isset($arguments['teamcityLogfile'])) {
             $result->addListener(
-                new TeamCity($arguments['teamcityLogfile'])
+                new TeamCity($arguments['teamcityLogfile']),
             );
         }
 
@@ -374,8 +374,8 @@ final class TestRunner extends BaseTestRunner
             $result->addListener(
                 new JUnit(
                     $arguments['junitLogfile'],
-                    $arguments['reportUselessTests']
-                )
+                    $arguments['reportUselessTests'],
+                ),
             );
         }
 
@@ -432,7 +432,7 @@ final class TestRunner extends BaseTestRunner
 
                     (new FilterMapper)->map(
                         $this->codeCoverageFilter,
-                        $codeCoverageConfiguration
+                        $codeCoverageConfiguration,
                     );
                 }
             }
@@ -449,7 +449,7 @@ final class TestRunner extends BaseTestRunner
 
                 $codeCoverage = new CodeCoverage(
                     $codeCoverageDriver,
-                    $this->codeCoverageFilter
+                    $this->codeCoverageFilter,
                 );
 
                 if (isset($codeCoverageConfiguration) && $codeCoverageConfiguration->hasCacheDirectory()) {
@@ -532,21 +532,21 @@ final class TestRunner extends BaseTestRunner
 
                 $this->writeMessage(
                     'Configuration',
-                    $arguments['configurationObject']->filename()
+                    $arguments['configurationObject']->filename(),
                 );
             }
 
             foreach ($arguments['loadedExtensions'] as $extension) {
                 $this->writeMessage(
                     'Extension',
-                    $extension
+                    $extension,
                 );
             }
 
             foreach ($arguments['notLoadedExtensions'] as $extension) {
                 $this->writeMessage(
                     'Extension',
-                    $extension
+                    $extension,
                 );
             }
         }
@@ -554,7 +554,7 @@ final class TestRunner extends BaseTestRunner
         if ($arguments['executionOrder'] === TestSuiteSorter::ORDER_RANDOMIZED) {
             $this->writeMessage(
                 'Random Seed',
-                (string) $arguments['randomOrderSeed']
+                (string) $arguments['randomOrderSeed'],
             );
         }
 
@@ -586,7 +586,7 @@ final class TestRunner extends BaseTestRunner
                     $this->writeMessage('Suggestion', 'Migrate your XML configuration using "--migrate-configuration"!');
                 } else {
                     $this->write(
-                        "\n  Warning - The configuration file did not pass validation!\n  The following problems have been detected:\n"
+                        "\n  Warning - The configuration file did not pass validation!\n  The following problems have been detected:\n",
                     );
 
                     $this->write($arguments['configurationObject']->validationErrors());
@@ -660,6 +660,21 @@ final class TestRunner extends BaseTestRunner
         $this->printer->printResult($result);
 
         if (isset($codeCoverage)) {
+            if (isset($arguments['coveragePHP'])) {
+                $this->codeCoverageGenerationStart('PHP');
+
+                try {
+                    $writer = new PhpReport;
+                    $writer->process($codeCoverage, $arguments['coveragePHP']);
+
+                    $this->codeCoverageGenerationSucceeded();
+
+                    unset($writer);
+                } catch (CodeCoverageException $e) {
+                    $this->codeCoverageGenerationFailed($e);
+                }
+            }
+
             if (isset($arguments['coverageClover'])) {
                 $this->codeCoverageGenerationStart('Clover XML');
 
@@ -714,8 +729,8 @@ final class TestRunner extends BaseTestRunner
                         $arguments['reportHighLowerBound'],
                         sprintf(
                             ' and <a href="https://phpunit.de/">PHPUnit %s</a>',
-                            Version::id()
-                        )
+                            Version::id(),
+                        ),
                     );
 
                     $writer->process($codeCoverage, $arguments['coverageHtml']);
@@ -728,21 +743,6 @@ final class TestRunner extends BaseTestRunner
                 }
             }
 
-            if (isset($arguments['coveragePHP'])) {
-                $this->codeCoverageGenerationStart('PHP');
-
-                try {
-                    $writer = new PhpReport;
-                    $writer->process($codeCoverage, $arguments['coveragePHP']);
-
-                    $this->codeCoverageGenerationSucceeded();
-
-                    unset($writer);
-                } catch (CodeCoverageException $e) {
-                    $this->codeCoverageGenerationFailed($e);
-                }
-            }
-
             if (isset($arguments['coverageText'])) {
                 if ($arguments['coverageText'] === 'php://stdout') {
                     $outputStream = $this->printer;
@@ -756,11 +756,11 @@ final class TestRunner extends BaseTestRunner
                     $arguments['reportLowUpperBound'],
                     $arguments['reportHighLowerBound'],
                     $arguments['coverageTextShowUncoveredFiles'],
-                    $arguments['coverageTextShowOnlySummary']
+                    $arguments['coverageTextShowOnlySummary'],
                 );
 
                 $outputStream->write(
-                    $processor->process($codeCoverage, $colors)
+                    $processor->process($codeCoverage, $colors),
                 );
             }
 
@@ -864,8 +864,8 @@ final class TestRunner extends BaseTestRunner
     }
 
     /**
-     * @throws \PHPUnit\TextUI\XmlConfiguration\Exception
      * @throws Exception
+     * @throws XmlConfiguration\Exception
      */
     private function handleConfiguration(array &$arguments): void
     {
@@ -1006,7 +1006,7 @@ final class TestRunner extends BaseTestRunner
                 $arguments['excludeGroups'] = array_diff($groupConfiguration->exclude()->asArrayOfStrings(), $groupCliArgs);
             }
 
-            if (!isset($this->arguments['noExtensions'])) {
+            if (!isset($arguments['noExtensions'])) {
                 $extensionHandler = new ExtensionHandler;
 
                 foreach ($arguments['configurationObject']->extensions() as $extension) {
@@ -1023,7 +1023,7 @@ final class TestRunner extends BaseTestRunner
             foreach ($arguments['unavailableExtensions'] as $extension) {
                 $arguments['warnings'][] = sprintf(
                     'Extension "%s" is not available',
-                    $extension
+                    $extension,
                 );
             }
 
@@ -1033,7 +1033,7 @@ final class TestRunner extends BaseTestRunner
                 if ($loggingConfiguration->hasText()) {
                     $arguments['listeners'][] = new DefaultResultPrinter(
                         $loggingConfiguration->text()->target()->path(),
-                        true
+                        true,
                     );
                 }
 
@@ -1147,14 +1147,14 @@ final class TestRunner extends BaseTestRunner
         if (!empty($arguments['excludeGroups'])) {
             $filterFactory->addFilter(
                 new ReflectionClass(ExcludeGroupFilterIterator::class),
-                $arguments['excludeGroups']
+                $arguments['excludeGroups'],
             );
         }
 
         if (!empty($arguments['groups'])) {
             $filterFactory->addFilter(
                 new ReflectionClass(IncludeGroupFilterIterator::class),
-                $arguments['groups']
+                $arguments['groups'],
             );
         }
 
@@ -1166,8 +1166,8 @@ final class TestRunner extends BaseTestRunner
                     {
                         return '__phpunit_covers_' . $name;
                     },
-                    $arguments['testsCovering']
-                )
+                    $arguments['testsCovering'],
+                ),
             );
         }
 
@@ -1179,15 +1179,15 @@ final class TestRunner extends BaseTestRunner
                     {
                         return '__phpunit_uses_' . $name;
                     },
-                    $arguments['testsUsing']
-                )
+                    $arguments['testsUsing'],
+                ),
             );
         }
 
         if ($arguments['filter']) {
             $filterFactory->addFilter(
                 new ReflectionClass(NameFilterIterator::class),
-                $arguments['filter']
+                $arguments['filter'],
             );
         }
 
@@ -1204,8 +1204,8 @@ final class TestRunner extends BaseTestRunner
             sprintf(
                 "%-15s%s\n",
                 $type . ':',
-                $message
-            )
+                $message,
+            ),
         );
 
         $this->messagePrinted = true;
@@ -1219,7 +1219,7 @@ final class TestRunner extends BaseTestRunner
             $arguments['colors'],
             $arguments['debug'],
             $arguments['columns'],
-            $arguments['reverseList']
+            $arguments['reverseList'],
         );
 
         assert($object instanceof ResultPrinter);
@@ -1232,8 +1232,8 @@ final class TestRunner extends BaseTestRunner
         $this->write(
             sprintf(
                 "\nGenerating code coverage report in %s format ... ",
-                $format
-            )
+                $format,
+            ),
         );
 
         $this->timer->start();
@@ -1244,8 +1244,8 @@ final class TestRunner extends BaseTestRunner
         $this->write(
             sprintf(
                 "done [%s]\n",
-                $this->timer->stop()->asString()
-            )
+                $this->timer->stop()->asString(),
+            ),
         );
     }
 
@@ -1255,8 +1255,8 @@ final class TestRunner extends BaseTestRunner
             sprintf(
                 "failed [%s]\n%s\n",
                 $this->timer->stop()->asString(),
-                $e->getMessage()
-            )
+                $e->getMessage(),
+            ),
         );
     }
 }
