@@ -7,9 +7,10 @@
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
-
 namespace PHPUnit\TestFixture;
 
+use stdClass;
+
 class ClassWithStaticReturnTypes
 {
     public function returnsStatic(): static
@@ -20,7 +21,7 @@ class ClassWithStaticReturnTypes
     {
     }
 
-    public function returnsUnionWithStatic(): static|\stdClass
+    public function returnsUnionWithStatic(): static|stdClass
     {
     }
 }
