@@ -7,7 +7,7 @@
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
-require_once __DIR__ . '/InheritanceB.php';
+namespace PHPUnit\TestFixture\Inheritance;
 
 class InheritanceA extends InheritanceB
 {
