@@ -16,12 +16,12 @@ final class TestWithDifferentStatuses extends TestCase
 {
     public function testThatFails(): void
     {
-        $this->fail();
+        $this->assertTrue(false);
     }
 
     public function testThatErrors(): void
     {
-        throw new Exception();
+        throw new Exception;
     }
 
     public function testThatPasses(): void
@@ -51,12 +51,13 @@ final class TestWithDifferentStatuses extends TestCase
 
     public function testWithCreatePartialMockWarning(): void
     {
-        $this->createPartialMock(\PHPUnit\TestFixture\Mockable::class, ['mockableMethod', 'fakeMethod1', 'fakeMethod2']);
+        $this->createPartialMock(Mockable::class, ['mockableMethod', 'fakeMethod1', 'fakeMethod2']);
     }
 
     public function testWithCreatePartialMockPassesNoWarning(): void
     {
-        $mock = $this->createPartialMock(\PHPUnit\TestFixture\Mockable::class, ['mockableMethod']);
+        $mock = $this->createPartialMock(Mockable::class, ['mockableMethod']);
+
         $this->assertNull($mock->mockableMethod());
     }
 }
