@@ -8,6 +8,8 @@
  * file that was distributed with this source code.
  */
 use PHPUnit\Framework\TestSuite;
+use PHPUnit\TestFixture\DependencyFailureTest;
+use PHPUnit\TestFixture\DependencySuccessTest;
 
 class DependencyTestSuite
 {
