@@ -7,7 +7,7 @@
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
-class Issue3093Test extends \PHPUnit\Framework\TestCase
+class Issue3093Test extends PHPUnit\Framework\TestCase
 {
     public function someDataProvider(): array
     {
