@@ -35,7 +35,7 @@ final class InvocationMockerTest extends TestCase
             ->getMock();
 
         $mock->method('foo')
-             ->willReturn(1);
+            ->willReturn(1);
 
         $this->assertEquals(1, $mock->foo());
     }
@@ -47,7 +47,7 @@ final class InvocationMockerTest extends TestCase
             ->getMock();
 
         $mock->method('foo')
-             ->willReturn(1, 2, 3);
+            ->willReturn(1, 2, 3);
 
         $this->assertEquals(1, $mock->foo());
         $this->assertEquals(2, $mock->foo());
@@ -61,7 +61,7 @@ final class InvocationMockerTest extends TestCase
             ->getMock();
 
         $mock->method('foo')
-             ->willReturnOnConsecutiveCalls(1, 2, 3);
+            ->willReturnOnConsecutiveCalls(1, 2, 3);
 
         $this->assertEquals(1, $mock->foo());
         $this->assertEquals(2, $mock->foo());
@@ -75,7 +75,7 @@ final class InvocationMockerTest extends TestCase
             ->getMock();
 
         $mock->method('foo')
-             ->willReturnReference($value);
+            ->willReturnReference($value);
 
         $this->assertNull($mock->foo());
         $value = 'foo';
@@ -90,7 +90,7 @@ final class InvocationMockerTest extends TestCase
 
         $invocationMocker = new InvocationMocker(
             $matcherCollection,
-            new Matcher($this->any())
+            new Matcher($this->any()),
         );
 
         $this->expectException(MethodCannotBeConfiguredException::class);
@@ -145,7 +145,7 @@ final class InvocationMockerTest extends TestCase
         $this->expectExceptionMessage(sprintf(
             'Method methodWithClassReturnTypeDeclaration may not return value of type %s, its declared return type is "%s"',
             Foo::class,
-            stdClass::class
+            stdClass::class,
         ));
         $invocationMocker->willReturn(new Foo);
     }
@@ -169,7 +169,7 @@ final class InvocationMockerTest extends TestCase
             ->getMock();
 
         $mock->method('methodWithBoolReturnTypeDeclaration')
-             ->willReturn(true);
+            ->willReturn(true);
 
         $this->assertEquals(true, $mock->methodWithBoolReturnTypeDeclaration());
     }
@@ -180,7 +180,7 @@ final class InvocationMockerTest extends TestCase
             ->getMock();
 
         $mock->method('methodWithBoolReturnTypeDeclaration')
-             ->willReturn(true);
+            ->willReturn(true);
 
         $this->assertEquals(true, $mock->methodwithboolreturntypedeclaration());
     }
@@ -191,7 +191,7 @@ final class InvocationMockerTest extends TestCase
             ->getMock();
 
         $mock->method('methodwithboolreturntypedeclaration')
-             ->willReturn(true);
+            ->willReturn(true);
 
         $this->assertEquals(true, $mock->methodWithBoolReturnTypeDeclaration());
     }
@@ -250,10 +250,10 @@ final class InvocationMockerTest extends TestCase
             ->getMock();
 
         $mock->method('foo')
-             ->willReturn(new ReturnStub('foo'));
+            ->willReturn(new ReturnStub('foo'));
 
         $mock->method('bar')
-             ->willReturn(new ReturnSelf);
+            ->willReturn(new ReturnSelf);
 
         $this->assertSame('foo', $mock->foo());
         $this->assertSame($mock, $mock->bar());
