@@ -37,8 +37,8 @@ final class MockBuilderTest extends TestCase
     public function testMethodsToMockCanBeSpecified(): void
     {
         $mock = $this->getMockBuilder(Mockable::class)
-                     ->onlyMethods(['mockableMethod'])
-                     ->getMock();
+            ->onlyMethods(['mockableMethod'])
+            ->getMock();
 
         $this->assertNull($mock->mockableMethod());
         $this->assertTrue($mock->anotherMockableMethod());
@@ -47,8 +47,8 @@ final class MockBuilderTest extends TestCase
     public function testSetMethodsAllowsNonExistentMethodNames(): void
     {
         $mock = $this->getMockBuilder(Mockable::class)
-                     ->setMethods(['mockableMethodWithCrazyName'])
-                     ->getMock();
+            ->setMethods(['mockableMethodWithCrazyName'])
+            ->getMock();
 
         $this->assertNull($mock->mockableMethodWithCrazyName());
     }
@@ -58,19 +58,19 @@ final class MockBuilderTest extends TestCase
         $this->expectException(CannotUseOnlyMethodsException::class);
         $this->expectExceptionMessage(sprintf(
             'Trying to configure method "mockableMethodWithCrazyName" with onlyMethods(), but it does not exist in class "%s". Use addMethods() for methods that do not exist in the class',
-            Mockable::class
+            Mockable::class,
         ));
 
         $this->getMockBuilder(Mockable::class)
-             ->onlyMethods(['mockableMethodWithCrazyName'])
-             ->getMock();
+            ->onlyMethods(['mockableMethodWithCrazyName'])
+            ->getMock();
     }
 
     public function testOnlyMethodsWithExistingMethodNames(): void
     {
         $mock = $this->getMockBuilder(Mockable::class)
-                     ->onlyMethods(['mockableMethod'])
-                     ->getMock();
+            ->onlyMethods(['mockableMethod'])
+            ->getMock();
 
         $this->assertNull($mock->mockableMethod());
         $this->assertTrue($mock->anotherMockableMethod());
@@ -79,8 +79,8 @@ final class MockBuilderTest extends TestCase
     public function testOnlyMethodsWithEmptyArray(): void
     {
         $mock = $this->getMockBuilder(Mockable::class)
-                     ->onlyMethods([])
-                     ->getMock();
+            ->onlyMethods([])
+            ->getMock();
 
         $this->assertTrue($mock->mockableMethod());
     }
@@ -90,19 +90,19 @@ final class MockBuilderTest extends TestCase
         $this->expectException(CannotUseAddMethodsException::class);
         $this->expectExceptionMessage(sprintf(
             'Trying to configure method "mockableMethod" with addMethods(), but it exists in class "%s". Use onlyMethods() for methods that exist in the class',
-            Mockable::class
+            Mockable::class,
         ));
 
         $this->getMockBuilder(Mockable::class)
-             ->addMethods(['mockableMethod'])
-             ->getMock();
+            ->addMethods(['mockableMethod'])
+            ->getMock();
     }
 
     public function testAddMethodsWithExistingMethodNames(): void
     {
         $mock = $this->getMockBuilder(Mockable::class)
-                     ->addMethods(['mockableMethodWithFakeMethod'])
-                     ->getMock();
+            ->addMethods(['mockableMethodWithFakeMethod'])
+            ->getMock();
 
         $this->assertNull($mock->mockableMethodWithFakeMethod());
         $this->assertTrue($mock->anotherMockableMethod());
@@ -111,8 +111,8 @@ final class MockBuilderTest extends TestCase
     public function testAddMethodsWithEmptyArray(): void
     {
         $mock = $this->getMockBuilder(Mockable::class)
-                     ->addMethods([])
-                     ->getMock();
+            ->addMethods([])
+            ->getMock();
 
         $this->assertTrue($mock->mockableMethod());
     }
@@ -120,9 +120,9 @@ final class MockBuilderTest extends TestCase
     public function testAbleToUseAddMethodsAfterOnlyMethods(): void
     {
         $mock = $this->getMockBuilder(Mockable::class)
-                     ->onlyMethods(['mockableMethod'])
-                     ->addMethods(['mockableMethodWithFakeMethod'])
-                     ->getMock();
+            ->onlyMethods(['mockableMethod'])
+            ->addMethods(['mockableMethodWithFakeMethod'])
+            ->getMock();
 
         $this->assertNull($mock->mockableMethod());
         $this->assertNull($mock->mockableMethodWithFakeMethod());
@@ -131,9 +131,9 @@ final class MockBuilderTest extends TestCase
     public function testAbleToUseOnlyMethodsAfterAddMethods(): void
     {
         $mock = $this->getMockBuilder(Mockable::class)
-                     ->addMethods(['mockableMethodWithFakeMethod'])
-                     ->onlyMethods(['mockableMethod'])
-                     ->getMock();
+            ->addMethods(['mockableMethodWithFakeMethod'])
+            ->onlyMethods(['mockableMethod'])
+            ->getMock();
 
         $this->assertNull($mock->mockableMethodWithFakeMethod());
         $this->assertNull($mock->mockableMethod());
@@ -142,9 +142,9 @@ final class MockBuilderTest extends TestCase
     public function testAbleToUseSetMethodsAfterOnlyMethods(): void
     {
         $mock = $this->getMockBuilder(Mockable::class)
-                     ->onlyMethods(['mockableMethod'])
-                     ->setMethods(['mockableMethodWithCrazyName'])
-                     ->getMock();
+            ->onlyMethods(['mockableMethod'])
+            ->setMethods(['mockableMethodWithCrazyName'])
+            ->getMock();
 
         $this->assertNull($mock->mockableMethodWithCrazyName());
     }
@@ -152,9 +152,9 @@ final class MockBuilderTest extends TestCase
     public function testAbleToUseSetMethodsAfterAddMethods(): void
     {
         $mock = $this->getMockBuilder(Mockable::class)
-                     ->addMethods(['notAMethod'])
-                     ->setMethods(['mockableMethodWithCrazyName'])
-                     ->getMock();
+            ->addMethods(['notAMethod'])
+            ->setMethods(['mockableMethodWithCrazyName'])
+            ->getMock();
 
         $this->assertNull($mock->mockableMethodWithCrazyName());
     }
@@ -162,9 +162,9 @@ final class MockBuilderTest extends TestCase
     public function testAbleToUseAddMethodsAfterSetMethods(): void
     {
         $mock = $this->getMockBuilder(Mockable::class)
-                     ->setMethods(['mockableMethod'])
-                     ->addMethods(['mockableMethodWithFakeMethod'])
-                     ->getMock();
+            ->setMethods(['mockableMethod'])
+            ->addMethods(['mockableMethodWithFakeMethod'])
+            ->getMock();
 
         $this->assertNull($mock->mockableMethod());
         $this->assertNull($mock->mockableMethodWithFakeMethod());
@@ -173,9 +173,9 @@ final class MockBuilderTest extends TestCase
     public function testAbleToUseOnlyMethodsAfterSetMethods(): void
     {
         $mock = $this->getMockBuilder(Mockable::class)
-                     ->setMethods(['mockableMethodWithFakeMethod'])
-                     ->onlyMethods(['mockableMethod'])
-                     ->getMock();
+            ->setMethods(['mockableMethodWithFakeMethod'])
+            ->onlyMethods(['mockableMethod'])
+            ->getMock();
 
         $this->assertNull($mock->mockableMethod());
         $this->assertNull($mock->mockableMethodWithFakeMethod());
@@ -184,9 +184,9 @@ final class MockBuilderTest extends TestCase
     public function testAbleToUseAddMethodsAfterSetMethodsWithNull(): void
     {
         $mock = $this->getMockBuilder(Mockable::class)
-                     ->setMethods()
-                     ->addMethods(['mockableMethodWithFakeMethod'])
-                     ->getMock();
+            ->setMethods()
+            ->addMethods(['mockableMethodWithFakeMethod'])
+            ->getMock();
 
         $this->assertNull($mock->mockableMethodWithFakeMethod());
     }
@@ -201,8 +201,8 @@ final class MockBuilderTest extends TestCase
     public function testMockClassNameCanBeSpecified(): void
     {
         $mock = $this->getMockBuilder(Mockable::class)
-                     ->setMockClassName(ACustomClassName::class)
-                     ->getMock();
+            ->setMockClassName(ACustomClassName::class)
+            ->getMock();
 
         $this->assertInstanceOf(ACustomClassName::class, $mock);
     }
@@ -210,8 +210,8 @@ final class MockBuilderTest extends TestCase
     public function testConstructorArgumentsCanBeSpecified(): void
     {
         $mock = $this->getMockBuilder(Mockable::class)
-                     ->setConstructorArgs([23, 42])
-                     ->getMock();
+            ->setConstructorArgs([23, 42])
+            ->getMock();
 
         $this->assertEquals([23, 42], $mock->constructorArgs);
     }
@@ -219,8 +219,8 @@ final class MockBuilderTest extends TestCase
     public function testOriginalConstructorCanBeDisabled(): void
     {
         $mock = $this->getMockBuilder(Mockable::class)
-                     ->disableOriginalConstructor()
-                     ->getMock();
+            ->disableOriginalConstructor()
+            ->getMock();
 
         $this->assertNull($mock->constructorArgs);
     }
@@ -228,7 +228,7 @@ final class MockBuilderTest extends TestCase
     public function testByDefaultOriginalCloneIsPreserved(): void
     {
         $mock = $this->getMockBuilder(Mockable::class)
-                     ->getMock();
+            ->getMock();
 
         $cloned = clone $mock;
 
@@ -238,8 +238,8 @@ final class MockBuilderTest extends TestCase
     public function testOriginalCloneCanBeDisabled(): void
     {
         $mock = $this->getMockBuilder(Mockable::class)
-                     ->disableOriginalClone()
-                     ->getMock();
+            ->disableOriginalClone()
+            ->getMock();
 
         $mock->cloned = false;
         $cloned       = clone $mock;
@@ -250,12 +250,12 @@ final class MockBuilderTest extends TestCase
     public function testProvidesAFluentInterface(): void
     {
         $spec = $this->getMockBuilder(Mockable::class)
-                     ->onlyMethods(['mockableMethod'])
-                     ->setConstructorArgs([])
-                     ->setMockClassName('DummyClassName')
-                     ->disableOriginalConstructor()
-                     ->disableOriginalClone()
-                     ->disableAutoload();
+            ->onlyMethods(['mockableMethod'])
+            ->setConstructorArgs([])
+            ->setMockClassName('DummyClassName')
+            ->disableOriginalConstructor()
+            ->disableOriginalClone()
+            ->disableAutoload();
 
         $this->assertInstanceOf(MockBuilder::class, $spec);
     }
